@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_ActionError.php 490 2007-12-18 18:51:18Z mumumu-org $
+ *  @version    $Id: Ethna_ActionError.php 720 2009-02-04 16:14:55Z mumumu-org $
  */
 
 // {{{ Ethna_ActionError
@@ -199,7 +199,7 @@ class Ethna_ActionError
      */
     function &_getActionForm()
     {
-        if (is_null($this->action_form)) {
+        if (isset($this->action_form) == false) {
             $controller =& Ethna_Controller::getInstance();
             $this->action_form =& $controller->getActionForm();
         }
