@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_Controller.php 516 2008-04-30 16:30:05Z mumumu-org $
+ *  @version    $Id: Ethna_Controller.php 714 2009-02-04 14:25:26Z mumumu-org $
  */
 
 // {{{ Ethna_Controller
@@ -302,10 +302,14 @@ class Ethna_Controller
             || strcasecmp($id, 'app') === 0) {
             return Ethna::raiseError("Application Id [$id] is reserved\n");
         }
-        if (preg_match('/^[0-9a-zA-Z]+$/', $id) === 0) {
-            return Ethna::raiseError(
-                "Only Numeric(0-9) and Alphabetical(A-Z) is allowed for Application Id\n"
-            );
+
+        //    ץꥱIDϥ饹̾prefixȤʤ뤿ᡢ
+        //    ǻϤޤäƤƤϤʤ
+        if (preg_match('/^[a-zA-Z][a-zA-Z0-9]*$/', $id) === 0) {
+            $msg = (preg_match('/^[0-9]$/', $id[0]))
+                 ? "Application ID must NOT start with Number.\n"
+                 : "Only Numeric(0-9) and Alphabetical(A-Z) is allowed for Application Id\n";
+            return Ethna::raiseError($msg);
         }
         return $true;
     }
