@@ -5,7 +5,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_SmartyPlugin.php 489 2007-12-18 17:13:19Z mumumu-org $
+ *  @version    $Id: Ethna_SmartyPlugin.php 725 2009-02-05 16:59:45Z mumumu-org $
  */
 
 // {{{ smarty_modifier_number_format
@@ -196,9 +196,9 @@ function smarty_modifier_unique($array, $key = null)
             if (isset($v[$key]) == false) {
                 continue;
             }
-            $tmp[$v[$key]] = $v;
+            $tmp[] = $v[$key];
         }
-        return $tmp;
+        return array_unique($tmp);
     } else {
         return array_unique($array);
     }
@@ -323,16 +323,16 @@ function smarty_modifier_i18n($string)
  *  </code>
  *  <code>
  *  <input type="checkbox" name="test">
- *  <input type="checkbox" name="test" checkbox>
+ *  <input type="checkbox" name="test" checked>
  *  </code>
  *
- *  @param  string  $string åܥåϤ줿ե
- *  @return string  $stringʸ󤢤뤤0ʳξ"checked"
+ *  @param  string  $string åܥåϤ줿ե(顼Τ)
+ *  @return string  $stringʸ󤢤뤤0, null, false ʳξ"checked"
  */
 function smarty_modifier_checkbox($string)
 {
-    if ($string != "" && $string != 0) {
-        return "checked";
+    if (is_scalar($string) && $string != "" && $string != "0") {
+        return 'checked="checked"';
     }
 }
 // }}}
@@ -352,7 +352,7 @@ function smarty_modifier_checkbox($string)
  *  <option value="2" {$form|select:"2"}>bar</option>
  *  </code>
  *  <code>
- *  <option value="1" selected>foo</option>
+ *  <option value="1" selected="selected">foo</option>
  *  <option value="2" >bar</option>
  *  </code>
  *
@@ -362,8 +362,14 @@ function smarty_modifier_checkbox($string)
  */
 function smarty_modifier_select($string, $value)
 {
+    //    ɸ˹碌
+    //    @see http://www.w3.org/TR/html401/interact/forms.html#adef-selected
+    //    @see http://www.w3.org/TR/2000/REC-xhtml1-20000126/DTD/xhtml1-transitional.dtd
+    //    @see http://www.w3.org/TR/2000/REC-xhtml1-20000126/DTD/xhtml1-strict.dtd
+    //    @see http://www.w3.org/TR/2000/REC-xhtml1-20000126/DTD/xhtml1-frameset.dtd
+    //    @see http://www.w3.org/TR/xhtml-modularization/abstract_modules.html#s_sformsmodule
     if ($string == $value) {
-        return 'selected="true"';
+        return 'selected="selected"';
     }
 }
 // }}}
@@ -483,6 +489,24 @@ function smarty_function_uniqid($params, &$smarty)
 /**
  *  smarty function:쥯ȥե
  *
+ *  sample:
+ *  <code>
+ *  $smarty->assign('hoge',
+ *                   array(
+ *                       '1' => array('name' => 'foo'),
+ *                       '2' => array('name' => 'bar')
+ *                   )
+ *  );
+ *  {select list=$hoge name="hoge" value="1" empty="-- please select --"}
+ *  </code>
+ *  <code>
+ *  <select name="hoge">
+ *    <option value="">-- please select --</option>
+ *    <option value="1" selected="selected">foo</option>
+ *    <option value="2">bar</option>
+ *  </select>
+ *  </code>
+ *
  *  @param  array   $list   
  *  @param  string  $name   ե̾
  *  @param  string  $value  쥯ȥܥåϤ줿ե
@@ -498,7 +522,7 @@ function smarty_function_select($params, &$smarty)
         printf("<option value=\"\">%s</option>\n", $empty);
     }
     foreach ($list as $id => $elt) {
-        printf("<option value=\"%s\" %s>%s</option>\n", $id, $id == $value ? 'selected="true"' : '', $elt['name']);
+        printf("<option value=\"%s\" %s>%s</option>\n", $id, $id == $value ? 'selected="selected"' : '', $elt['name']);
     }
     print "</select>\n";
 }
