@@ -6,7 +6,7 @@
  *  @author     ICHII Takashi <ichii386@schweetheart.jp>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_Plugin_Validator_Required.php 298 2006-07-19 05:22:39Z fujimoto $
+ *  @version    $Id: Ethna_Plugin_Validator_Required.php 726 2009-02-05 18:27:20Z mumumu-org $
  */
 
 // {{{ Ethna_Plugin_Validator_Required
@@ -73,7 +73,7 @@ class Ethna_Plugin_Validator_Required extends Ethna_Plugin_Validator
         $valid_keys = array();
         if ($var != null) {
             foreach (array_keys($var) as $key) {
-                if ($this->isEmpty($var[$key], $form_def['type']) == false) {
+                if ($this->isEmpty($var[$key], $this->getFormType($name)) == false) {
                     $valid_keys[] = $key;
                 }
             }
