@@ -4,7 +4,7 @@
  *
  *  @author    {$author}
  *  @package   {$project_id}
- *  @version   $Id: app.action.default.php 387 2006-11-06 14:31:24Z cocoitiban $
+ *  @version   $Id: app.action.default.php 728 2009-02-05 18:36:10Z mumumu-org $
  */
 
 /**
@@ -18,7 +18,7 @@
 class {$project_id}_Form_Index extends {$project_id}_ActionForm
 {
     /** @var    bool    Хǡ˥ץ饰Ȥե饰 */
-    var $use_validator_plugin = false;
+    var $use_validator_plugin = true;
 
     /**
      *  @access   private
