@@ -4,7 +4,7 @@
  *
  *  @author     {$author}
  *  @package    {$project_id}
- *  @version    $Id: skel.view_test.php 209 2006-03-23 13:16:37Z fujimoto $
+ *  @version    $Id: skel.view_test.php 503 2008-04-25 04:06:08Z mumumu-org $
  */
 
 /**
@@ -47,16 +47,23 @@ class {$view_class}_TestCase extends Ethna_UnitTestCase
      *
      *  @access public
      */
-    /*
     function test_viewSample()
     {
+        /*
         // ե
         $this->af->set('id', 1);
 
         // {$forward_name}
         $this->vc->preforward();
         $this->assertNull($this->af->get('data'));
+        */
+
+        /**
+         *  TODO: ƥȥ򵭽ҤƲ
+         *  @see http://simpletest.org/en/first_test_tutorial.html
+         *  @see http://simpletest.org/en/unit_test_documentation.html
+         */
+        $this->fail('No Test! write Test!');
     }
-    */
 }
 ?>
